@@ -1,4 +1,4 @@
-#!/usr/pkg/bin/python3.13
+#!/usr/pkg/bin/python3.14
 
 import sys
 if __name__ == "__main__":
@@ -1349,7 +1349,7 @@ class PyShell(OutputWindow):
             self.text.see("insert")
             self.text.undo_block_stop()
 
-    _last_newline_re = re.compile(r"[ \t]*(\n[ \t]*)?\Z")
+    _last_newline_re = re.compile(r"[ \t]*(\n[ \t]*)?\z")
     def runit(self):
         index_before = self.text.index("end-2c")
         line = self.text.get("iomark", "end-1c")
